@@ -47,6 +47,7 @@ class TestHelpers(TestCase):
     def setup_temp_interface_config(self, interface):
         with open('/tmp/ifcfg-{0}'.format(interface), 'a+') as f:
             f.write(
+                'IPADDR=2.2.2.2\n'
                 'IPADDR999=1.1.1.1\n'
                 'ZONE=TestFirewalldZone\n'
                 '# Comment in file\n'
@@ -57,7 +58,7 @@ class TestHelpers(TestCase):
 
     def setup_temp_hostname(self):
         with open('/tmp/hostname', 'a+') as f:
-            f.write('This is a test file')
+            f.write('test.hostname.local')
 
     def setup_temp_network(self):
         with open('/tmp/network', 'a+') as f:
@@ -102,7 +103,7 @@ class TestHelpers(TestCase):
         with mock.patch(
             'novaagent.libs.centos.ServerOS._setup_hostname'
         ) as hostname:
-            hostname.return_value = 1, 'test_hostname'
+            hostname.return_value = 1, 'temp.hostname'
             with mock.patch('novaagent.utils.list_xenstore_macaddrs') as mac:
                 mac.return_value = ['BC764E206C5B']
                 with mock.patch('novaagent.utils.list_hw_interfaces') as hwint:
@@ -183,7 +184,7 @@ class TestHelpers(TestCase):
         with mock.patch(
             'novaagent.libs.centos.ServerOS._setup_hostname'
         ) as hostname:
-            hostname.return_value = 0, 'test_hostname'
+            hostname.return_value = 0, 'temp.hostname'
             with mock.patch('novaagent.utils.list_xenstore_macaddrs') as mac:
                 mac.return_value = ['BC764E206C5B']
                 with mock.patch('novaagent.utils.list_hw_interfaces') as hwint:
@@ -276,7 +277,7 @@ class TestHelpers(TestCase):
         with mock.patch(
             'novaagent.libs.centos.ServerOS._setup_hostname'
         ) as hostname:
-            hostname.return_value = 0, 'test_hostname'
+            hostname.return_value = 0, 'temp.hostname'
             with mock.patch('novaagent.utils.list_xenstore_macaddrs') as mac:
                 mac.return_value = ['BC764E206C5B']
                 with mock.patch('novaagent.utils.list_hw_interfaces') as hwint:
@@ -357,7 +358,7 @@ class TestHelpers(TestCase):
         with mock.patch(
             'novaagent.libs.centos.ServerOS._setup_hostname'
         ) as hostname:
-            hostname.return_value = 0, 'test_hostname'
+            hostname.return_value = 0, 'temp.hostname'
             with mock.patch('novaagent.utils.list_xenstore_macaddrs') as mac:
                 mac.return_value = ['BC764E206C5B']
                 with mock.patch('novaagent.utils.list_hw_interfaces') as hwint:
@@ -440,7 +441,7 @@ class TestHelpers(TestCase):
             with mock.patch(
                 'novaagent.libs.centos.ServerOS._setup_hostname'
             ) as hostname:
-                hostname.return_value = 0, 'test_hostname'
+                hostname.return_value = 0, 'temp.hostname'
                 with mock.patch(
                     'novaagent.utils.list_xenstore_macaddrs'
                 ) as mac:
@@ -530,7 +531,7 @@ class TestHelpers(TestCase):
             with mock.patch(
                 'novaagent.libs.centos.ServerOS._setup_hostname'
             ) as hostname:
-                hostname.return_value = 0, 'test_hostname'
+                hostname.return_value = 0, 'temp.hostname'
                 with mock.patch(
                     'novaagent.utils.list_xenstore_macaddrs'
                 ) as mac:
@@ -618,6 +619,22 @@ class TestHelpers(TestCase):
             'Did not get proper extra arguments from check'
         )
 
+    def test_check_extra_args_no_file(self):
+        temp = centos.ServerOS()
+        interface_file = '/tmp/ifcfg-eth1'
+
+        extra_args = temp._check_for_extra_settings(interface_file)
+        self.assertEqual(
+            len(extra_args),
+            0,
+            'Did not get proper number of arguments from check'
+        )
+        self.assertEqual(
+            extra_args,
+            [],
+            'Did not get proper extra arguments from check'
+        )
+
     def test_setup_routes(self):
         self.setup_temp_route()
         temp = centos.ServerOS()
@@ -693,9 +710,9 @@ class TestHelpers(TestCase):
         test_hostname = 'test.hostname'
         with mock.patch('novaagent.utils.get_hostname') as hostname:
             hostname.return_value = test_hostname
-            with mock.patch('novaagent.libs.centos.os.path.exists') as exists:
+            with mock.patch('novaagent.libs.os.path.exists') as exists:
                 exists.return_value = False
-                with mock.patch('novaagent.libs.centos.Popen') as popen:
+                with mock.patch('novaagent.libs.Popen') as popen:
                     popen.return_value.communicate.return_value = (
                         ('out', 'err')
                     )
@@ -722,9 +739,9 @@ class TestHelpers(TestCase):
         test_hostname = 'test.hostname'
         with mock.patch('novaagent.utils.get_hostname') as hostname:
             hostname.return_value = test_hostname
-            with mock.patch('novaagent.libs.centos.os.path.exists') as exists:
+            with mock.patch('novaagent.libs.os.path.exists') as exists:
                 exists.return_value = False
-                with mock.patch('novaagent.libs.centos.Popen') as popen:
+                with mock.patch('novaagent.libs.Popen') as popen:
                     popen.return_value.communicate.return_value = (
                         ('out', 'err')
                     )
@@ -751,9 +768,9 @@ class TestHelpers(TestCase):
         test_hostname = 'test.hostname'
         with mock.patch('novaagent.utils.get_hostname') as hostname:
             hostname.return_value = test_hostname
-            with mock.patch('novaagent.libs.centos.os.path.exists') as exists:
+            with mock.patch('novaagent.libs.os.path.exists') as exists:
                 exists.return_value = True
-                with mock.patch('novaagent.libs.centos.Popen') as popen:
+                with mock.patch('novaagent.libs.Popen') as popen:
                     popen.return_value.communicate.return_value = (
                         ('out', 'err')
                     )
@@ -780,9 +797,9 @@ class TestHelpers(TestCase):
         test_hostname = 'test.hostname'
         with mock.patch('novaagent.utils.get_hostname') as hostname:
             hostname.return_value = test_hostname
-            with mock.patch('novaagent.libs.centos.os.path.exists') as exists:
+            with mock.patch('novaagent.libs.os.path.exists') as exists:
                 exists.return_value = True
-                with mock.patch('novaagent.libs.centos.Popen') as popen:
+                with mock.patch('novaagent.libs.Popen') as popen:
                     popen.return_value.communicate.return_value = (
                         ('out', 'err')
                     )
